AutoTS — AutoTS 0.2.1 documentation

# AutoTS

autots is an automated time series forecasting package for Python.

Features:

- Twenty available model classes, with tens of thousands of possible hyperparameter configurations

- Finds optimal time series models by genetic programming

- Handles univariate and multivariate/parallel time series

## Installation

    pip install autots

Requirements: Python 3.5+, numpy, pandas, and scikit-learn.

# Getting Started

- Intro
- AutoTS
  - Features
  - Basic Use
  - How to Contribute:
- Tutorial
  - Extended Tutorial
  - Underlying Process
  - Deployment and Template Import/Export
  - Installation and Dependency Versioning
  - Caveats and Advice

# Modules API

- autots
  - autots package

# Indices and tables

- Index

- Module Index

- Search Page